Author: Human Person

Internet-Draft | xml2rfc index tests | June 2021
Person | Expires December 27, 2021 | [Page]

Workgroup:
  Network Working Group
Internet-Draft:
  indexes-00
Published:
  June 25, 2021
Intended Status:
  Experimental
Expires:
  December 27, 2021
Author:
  H. Person, Ed.

# xml2rfc index tests

## Status of This Memo

This Internet-Draft is submitted in full conformance with the provisions of BCP 78 and BCP 79.¶

Internet-Drafts are working documents of the Internet Engineering Task Force (IETF). Note that other groups may also distribute working documents as Internet-Drafts. The list of current Internet-Drafts is at https://datatracker.ietf.org/drafts/current/.¶

Internet-Drafts are draft documents valid for a maximum of six months and may be updated, replaced, or obsoleted by other documents at any time. It is inappropriate to use Internet-Drafts as reference material or to cite them other than as "work in progress."¶

This Internet-Draft will expire on December 27, 2021.¶

## Copyright Notice

Copyright (c) 2021 IETF Trust and the persons identified as the document authors. All rights reserved.¶

This document is subject to BCP 78 and the IETF Trust's Legal Provisions Relating to IETF Documents (https://trustee.ietf.org/license-info) in effect on the date of publication of this document. Please review these documents carefully, as they describe your rights and restrictions with respect to this document.¶

## 1. First Section

This is a section! Emphatically. Loudly. Subscripted. Superscripted. `Typewritten.` ¶

This is another section!¶

dt
  dd¶

- unnumbered item¶

1. numbered item¶

This is an aside.¶

> This is a blockquote.¶

Table 1
Table heading
¶
                                        printf("Hello world!\n");
¶

## 2. References

[ref0]
  Author, R. Q., "Reference". This is a reference not in a reference group.
[refgroup0]
  Author, R. Q., "Reference Group". This is a reference in a reference group.

## Index

A B D E F L S T¶

- A¶

  - annotation

      Reference [ref0]¶

      in reference group

        Reference [refgroup0]¶

- B¶

  - blockquote

      Section 1¶

- D¶

  - dd

      Section 1¶

    dt

      Section 1¶

- E¶

  - em

      Section 1, Paragraph 1¶

- F¶

  - figure

      Section 1, Paragraph 8.1.2.1.1¶

- L¶

  - li
      ol

        Section 1, Paragraph 5, Item 1¶

      ul

        Section 1, Paragraph 4, Item 1¶

- S¶

  - section

      Section 1¶

    strong

      Section 1, Paragraph 1¶

    sub

      Section 1, Paragraph 1¶

    sup

      Section 1, Paragraph 1¶

- T¶

  - t

      Section 1, Paragraph 1; Section 1, Paragraph 2¶

      in an aside tag

        Section 1, Paragraph 6.1¶

    table

      Table 1¶

    td

      Section 1, Paragraph 8.1.2.1.1¶

    th

      Table 1¶

    tt

      Section 1, Paragraph 1¶

## Author's Address